#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'moc-documentation-dock-widget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "libgui/src/moc-documentation-dock-widget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'moc-documentation-dock-widget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_octave__documentation_dock_widget_t {
    QByteArrayData data[13];
    char stringdata0[172];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__documentation_dock_widget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__documentation_dock_widget_t qt_meta_stringdata_octave__documentation_dock_widget = {
    {
QT_MOC_LITERAL(0, 0, 33), // "octave::documentation_dock_wi..."
QT_MOC_LITERAL(1, 34, 15), // "notice_settings"
QT_MOC_LITERAL(2, 50, 0), // ""
QT_MOC_LITERAL(3, 51, 19), // "const gui_settings*"
QT_MOC_LITERAL(4, 71, 8), // "settings"
QT_MOC_LITERAL(5, 80, 13), // "save_settings"
QT_MOC_LITERAL(6, 94, 13), // "copyClipboard"
QT_MOC_LITERAL(7, 108, 14), // "pasteClipboard"
QT_MOC_LITERAL(8, 123, 9), // "selectAll"
QT_MOC_LITERAL(9, 133, 7), // "showDoc"
QT_MOC_LITERAL(10, 141, 4), // "name"
QT_MOC_LITERAL(11, 146, 11), // "registerDoc"
QT_MOC_LITERAL(12, 158, 13) // "unregisterDoc"

    },
    "octave::documentation_dock_widget\0"
    "notice_settings\0\0const gui_settings*\0"
    "settings\0save_settings\0copyClipboard\0"
    "pasteClipboard\0selectAll\0showDoc\0name\0"
    "registerDoc\0unregisterDoc"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__documentation_dock_widget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x0a /* Public */,
       5,    0,   57,    2, 0x0a /* Public */,
       6,    0,   58,    2, 0x0a /* Public */,
       7,    0,   59,    2, 0x0a /* Public */,
       8,    0,   60,    2, 0x0a /* Public */,
       9,    1,   61,    2, 0x0a /* Public */,
      11,    1,   64,    2, 0x0a /* Public */,
      12,    1,   67,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void, QMetaType::QString,   10,

       0        // eod
};

void octave::documentation_dock_widget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        documentation_dock_widget *_t = static_cast<documentation_dock_widget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
        case 1: _t->save_settings(); break;
        case 2: _t->copyClipboard(); break;
        case 3: _t->pasteClipboard(); break;
        case 4: _t->selectAll(); break;
        case 5: _t->showDoc((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->registerDoc((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->unregisterDoc((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject octave::documentation_dock_widget::staticMetaObject = {
    { &octave_dock_widget::staticMetaObject, qt_meta_stringdata_octave__documentation_dock_widget.data,
      qt_meta_data_octave__documentation_dock_widget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::documentation_dock_widget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::documentation_dock_widget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__documentation_dock_widget.stringdata0))
        return static_cast<void*>(this);
    return octave_dock_widget::qt_metacast(_clname);
}

int octave::documentation_dock_widget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = octave_dock_widget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
